"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandLineUi = void 0;
const chalk = require("chalk");
const inquirer = require("inquirer");
const os = require("os");
const config_file_1 = require("./config-file/config-file");
class CommandLineUi {
    constructor(config) {
        this.config = config;
        this.consoleMenuTasks = this.createMenuFromConfig(config);
        this.uiOptions = {};
        let maxTaxId = -Infinity;
        for (const menuTask of this.consoleMenuTasks.tasks) {
            this.uiOptions[chalk.yellow(menuTask.label)] = menuTask.taskId;
            maxTaxId = Math.max(menuTask.taskId, maxTaxId);
        }
    }
    askForMenuOption() {
        return __awaiter(this, void 0, void 0, function* () {
            const questions = [
                {
                    name: 'choseOption',
                    type: 'rawlist',
                    message: 'Chose option',
                    choices: Object.keys(this.uiOptions),
                    validate: (value) => {
                        value = +value;
                        if (0 < value && value <= this.uiOptions[this.consoleMenuTasks.tasks.length - 1]) {
                            return true;
                        }
                        else {
                            return 'Please select one of the options';
                        }
                    },
                },
            ];
            const option = yield inquirer.prompt(questions);
            const selectedOption = option.choseOption;
            const selectedOptionTaskNumber = this.uiOptions[selectedOption];
            return this.consoleMenuTasks.tasks.find((t) => t.taskId === selectedOptionTaskNumber);
        });
    }
    printByeMessage() {
        console.log(chalk.yellow(`Bye bye ${os.EOL}`));
    }
    printError(error) {
        console.error(chalk.red(`${error.name} ${error.message} ${os.EOL}`), error.stack);
    }
    createMenuFromConfig(config) {
        const menuOptions = {
            tasks: [],
        };
        let taskId = 1;
        for (const taskDef of config.tasks) {
            if (taskDef.type === config_file_1.ConfigTaskTypes.ExportOrRunTablesAsSeed) {
                menuOptions.tasks.push({
                    taskDef,
                    runnerType: config_file_1.TaskTypes.ExportDataToSeedScripts,
                    label: `Export ${taskDef.label}`,
                    taskId: taskId,
                });
                taskId++;
                menuOptions.tasks.push({
                    taskDef,
                    runnerType: config_file_1.TaskTypes.RunSeedScriptsAgainstDatabase,
                    label: `Run ${taskDef.label}`,
                    taskId: taskId,
                });
                taskId++;
            }
            else if (taskDef.type === config_file_1.ConfigTaskTypes.ExportTablesAsCodeFile) {
                menuOptions.tasks.push({
                    taskDef,
                    runnerType: config_file_1.TaskTypes.ExportDataToCodeFile,
                    label: `Export ${taskDef.label}`,
                    taskId: taskId,
                });
                taskId++;
            }
        }
        menuOptions.tasks.push({
            taskDef: null,
            runnerType: config_file_1.TaskTypes.Exit,
            label: 'Exit',
            taskId: taskId,
        });
        return menuOptions;
    }
}
exports.CommandLineUi = CommandLineUi;
//# sourceMappingURL=command-line-ui.js.map