"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const clear = require("clear");
const process = require("process");
const command_line_ui_1 = require("./command-line-ui");
const config_file_1 = require("./config-file/config-file");
const config_file_reader_1 = require("./config-file/config-file-reader");
const get_orm_config_1 = require("./get-orm-config");
const logger_type_1 = require("./logging/logger.type");
const seed_data_logger_1 = require("./logging/seed-data-logger");
const seed_data_logger_adapter_1 = require("./logging/seed-data-logger-adapter");
const seed_runner_factory_1 = require("./seed-runner/seed-runner-factory");
const args = require('yargs').argv;
const loggerAdapter = new seed_data_logger_adapter_1.SeedDataLoggerAdapter(logger_type_1.LogLevel.debug, new seed_data_logger_1.SeedDataLogger());
const run = () => __awaiter(void 0, void 0, void 0, function* () {
    clear();
    const workingDirectory = process.cwd();
    const configFileReader = config_file_reader_1.configFileReaderFactory.createInstance(loggerAdapter);
    const configFile = yield configFileReader.readConfig(workingDirectory, args.config, args.dbUrl);
    const seedRunner = yield seed_runner_factory_1.seedRunnerFactory.createInstance((0, get_orm_config_1.getOrmConfig)(configFile.databaseUrl), loggerAdapter);
    const commandLineInterface = new command_line_ui_1.CommandLineUi(configFile);
    if (!configFile) {
        const error = new Error('Missing config file');
        commandLineInterface.printError(error);
        throw error;
    }
    let selectedTask;
    do {
        selectedTask = yield commandLineInterface.askForMenuOption();
        switch (selectedTask.runnerType) {
            case config_file_1.TaskTypes.ExportDataToSeedScripts:
                yield seedRunner.exportTablesAsSeed(selectedTask.taskDef);
                break;
            case config_file_1.TaskTypes.ExportDataToCodeFile:
                yield seedRunner.exportTablesToCode(selectedTask.taskDef.tables, selectedTask.taskDef.outDir);
                break;
            case config_file_1.TaskTypes.RunSeedScriptsAgainstDatabase:
                yield seedRunner.runSeeds(selectedTask.taskDef.tables, selectedTask.taskDef.excludeColumns, selectedTask.taskDef.outDir);
                break;
        }
    } while (selectedTask.runnerType !== config_file_1.TaskTypes.Exit);
    commandLineInterface.printByeMessage();
    process.exit(0);
});
run().catch((e) => {
    loggerAdapter.error(e, 'GlobalErrorHandler');
    process.exit(1);
});
//# sourceMappingURL=index.js.map