"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileStreamService = void 0;
const fs_1 = require("fs");
const stringify = require("json-stringify-deterministic");
const mkdirp = require("mkdirp");
const os = require("os");
const path = require("path");
const rimraf_1 = require("rimraf");
const sortKeysRecursive = require("sort-keys-recursive");
class FileStreamService {
    constructor(logger) {
        this.logger = logger;
    }
    writeFileWithString(filePath, fileName, content) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.writeFileAsync(filePath, fileName, () => Promise.resolve(content));
        });
    }
    writeFileWithObject(filePath, fileName, content, options = { space: '\t' }) {
        return __awaiter(this, void 0, void 0, function* () {
            const sortedObject = sortKeysRecursive(content);
            const objectAsString = stringify(sortedObject, options);
            yield this.writeFileAsync(filePath, fileName, () => Promise.resolve(objectAsString));
        });
    }
    resolve(segments) {
        return path.resolve(...segments);
    }
    endLine() {
        return os.EOL;
    }
    tabChar() {
        return `    `;
    }
    rmDir(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            yield (0, rimraf_1.rimraf)(directory);
        });
    }
    readFileAsJsonAsync(inputFile, errTransform) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.debug(`Read file ${inputFile}`, FileStreamService.name);
            try {
                const data = yield fs_1.promises.readFile(inputFile);
                const response = JSON.parse(data.toString());
                return response;
            }
            catch (err) {
                if (errTransform) {
                    return errTransform();
                }
                throw err;
            }
        });
    }
    readFileAsync(inputFile) {
        return __awaiter(this, void 0, void 0, function* () {
            return fs_1.promises.readFile(inputFile);
        });
    }
    writeFileAsync(filePath, fileName, getContent) {
        return __awaiter(this, void 0, void 0, function* () {
            const fileLocation = path.join(filePath, fileName);
            this.logger.debug(`Writing file: ${fileLocation}`, FileStreamService.name);
            yield mkdirp(filePath);
            const content = yield getContent();
            yield fs_1.promises.writeFile(fileLocation, content);
        });
    }
}
exports.FileStreamService = FileStreamService;
//# sourceMappingURL=file-stream.service.js.map