"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.seedRunnerFactory = exports.SeedRunnerFactory = void 0;
const typeorm_1 = require("typeorm");
const config_file_1 = require("../config-file/config-file");
const config_file_reader_1 = require("../config-file/config-file-reader");
const file_stream_service_1 = require("../io/file-stream.service");
const logger_type_1 = require("../logging/logger.type");
const seed_data_logger_adapter_1 = require("../logging/seed-data-logger-adapter");
const postgres_seed_query_runner_1 = require("./postgres-seed-query-runner");
const seed_data_runner_1 = require("./seed-data-runner");
class SeedRunnerFactory {
    createInstance(typeOrmConfig, logger) {
        return __awaiter(this, void 0, void 0, function* () {
            const fileStreamService = new file_stream_service_1.FileStreamService(logger);
            const dataSource = new typeorm_1.DataSource(typeOrmConfig);
            yield dataSource.initialize();
            const queryRunner = dataSource.createQueryRunner('master');
            const seedQueryRunner = new postgres_seed_query_runner_1.PostgresSeedQueryRunner(queryRunner, logger);
            const runner = new seed_data_runner_1.SeedDataRunner(seedQueryRunner, fileStreamService, logger);
            yield runner.isReadyToRun;
            return runner;
        });
    }
    runSeedScripts(dbConnection, externalLogger, configFile, queryRunner = undefined, logLevel = logger_type_1.LogLevel.info) {
        return __awaiter(this, void 0, void 0, function* () {
            const loggerAdapter = new seed_data_logger_adapter_1.SeedDataLoggerAdapter(logLevel, externalLogger);
            const fileStreamService = new file_stream_service_1.FileStreamService(loggerAdapter);
            const configFileReader = new config_file_reader_1.ConfigFileReader(fileStreamService);
            configFileReader.validate(configFile);
            queryRunner = queryRunner !== null && queryRunner !== void 0 ? queryRunner : dbConnection.createQueryRunner('master');
            const seedQueryRunner = new postgres_seed_query_runner_1.PostgresSeedQueryRunner(queryRunner, loggerAdapter);
            const runner = new seed_data_runner_1.SeedDataRunner(seedQueryRunner, fileStreamService, loggerAdapter);
            yield runner.isReadyToRun;
            const taskToRun = configFile.tasks.filter((t) => t.type === config_file_1.ConfigTaskTypes.ExportOrRunTablesAsSeed && t.runOnApplicationStartup);
            for (const task of taskToRun) {
                yield runner.runSeeds(task.tables, task.excludeColumns, task.outDir);
            }
        });
    }
}
exports.SeedRunnerFactory = SeedRunnerFactory;
exports.seedRunnerFactory = new SeedRunnerFactory();
//# sourceMappingURL=seed-runner-factory.js.map